@@ -1,14 +1,18 @@
-from vetmanager.url import Url, UrlFromGateway, \
-    HostGatewayUrl, BillingApiUrl, Domain
+from .url import Url, Protocol
+from .host import HostGatewayUrl, BillingApiUrl
+from .host import HostNameFromHostGateway, Domain
 from .token import Token, Credentials
 from .token import Login, Password, AppName
 
 
 def url(domain: str) -> Url:
-    return UrlFromGateway(
-        HostGatewayUrl(
-            BillingApiUrl("https://billing-api.vetmanager.cloud/"),
-            Domain(domain)
+    return Url(
+        Protocol('https'),
+        HostNameFromHostGateway(
+            HostGatewayUrl(
+                BillingApiUrl("https://billing-api.vetmanager.cloud/"),
+                Domain(domain)
+            )
         )
     )
 
